package Sys::Info::Driver::OSX::Device;
$Sys::Info::Driver::OSX::Device::VERSION = '0.7960';
use strict;
use warnings;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Sys::Info::Driver::OSX::Device

=head1 VERSION

version 0.7960

=head1 SYNOPSIS

    use parent qw( Sys::Info::Driver::OSX::Device );

=head1 DESCRIPTION

Base class for OSX device drivers.

=head1 NAME

Sys::Info::Driver::OSX::Device - Base class for OSX device drivers

=head1 METHODS

None.

=head1 AUTHOR

Burak Gursoy <burak@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Burak Gursoy.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
